﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SilverlightMultiLevelNavigationExample
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        // After the Frame navigates, ensure the HyperlinkButton representing the current page is selected
        private void ContentFrame_Navigated(object sender, NavigationEventArgs e)
        {
            foreach (var item in SubMenu.Items)
            {
                var hb = SubMenu.ItemContainerGenerator.ContainerFromItem(item).FindVisualChild<HyperlinkButton>();

                if (hb.NavigateUri.ToString().Equals(e.Uri.ToString()))
                {
                    VisualStateManager.GoToState(hb, "ActiveLink", true);
                }
                else
                {
                    VisualStateManager.GoToState(hb, "InactiveLink", true);
                }
            }

            foreach (var item in MainMenu.Items.OfType<MenuItem>())
            {
                var hb = MainMenu.ItemContainerGenerator.ContainerFromItem(item).FindVisualChild<HyperlinkButton>();

                if (item.SubMenuItems.Any(mnu => mnu.Url == e.Uri.ToString()))
                {
                    VisualStateManager.GoToState(hb, "ActiveLink", true);
                }
                else
                {
                    VisualStateManager.GoToState(hb, "InactiveLink", true);
                }
            }
        }

        // If an error occurs during navigation, show an error window
        private void ContentFrame_NavigationFailed(object sender, NavigationFailedEventArgs e)
        {
            e.Handled = true;
            ChildWindow errorWin = new ErrorWindow(e.Uri);
            errorWin.Show();
        }

        private void HyperlinkButton_Click(object sender, RoutedEventArgs e)
        {
            HyperlinkButton link = e.OriginalSource as HyperlinkButton;

            if (link != null)
            {
                if (link.DataContext != null)
                {
                    MenuItem item = link.DataContext as MenuItem;
                    if (item != null && item.SubMenuItems != null)
                    {
                        SubMenu.ItemsSource = item.SubMenuItems;
                        SubMenu.Visibility = Visibility.Visible;
                    }
                }
            }
        }
    }
}